@@ -9,7 +9,7 @@ from dynrender_skia.Core import DynRender
 from ..base.yt_dlp_parser import YtParser, YtVideoParseResult, YtImageParseResult
 from ...types.parse_result import VideoParseResult, ImageParseResult
 from ...config.config import DownloadConfig, GlobalConfig
-from ...types import DownloadResult, ParseError, Video
+from ...types import DownloadResult, ParseError, Video, UploadError
 from ...types.summary_result import SummaryResult
 from ...utiles.bilibili_api import BiliAPI
 from ...utiles.img_host import ImgHost
@@ -81,7 +81,7 @@ class BiliParse(YtParser):
     async def is_opus(self, url) -> str | None:
         """是动态"""
         async with httpx.AsyncClient(proxy=self.cfg.proxy) as cli:
-            url = str((await cli.get(url, follow_redirects=True)).url)
+            url = str((await cli.get(url, follow_redirects=True, timeout=30)).url)
         try:
             if bool(re.search(r"\b\d{18,19}\b", url).group(0)):
                 return url
@@ -99,6 +99,7 @@ class BiliParse(YtParser):
         if not data:
             raise ParseError("获取视频信息失败")
         duration = data["View"]["duration"]
+        dimension = data["View"]["dimension"]
         b3, b4 = await bili.get_buvid()
         if GlobalConfig.duration_limit and duration > 5400:  # 超过90分钟直接返回封面
             return BiliImageParseResult(
@@ -114,6 +115,7 @@ class BiliParse(YtParser):
             video_playurl = await bili.get_video_playurl(
                 bvid, data["View"]["cid"], b3, b4
             )
+
         durl = video_playurl["data"]["durl"][0]
         video_url = (
             self.change_source(durl["backup_url"][0])
@@ -123,7 +125,13 @@ class BiliParse(YtParser):
         return BiliVideoParseResult(
             title=data["View"]["title"],
             raw_url=url,
-            video=Video(video_url, thumb_url=data["View"]["pic"]),
+            video=Video(
+                video_url,
+                thumb_url=data["View"]["pic"],
+                duration=duration,
+                width=dimension.get("width", 0),
+                height=dimension.get("height", 0),
+            ),
         )
 
     async def ytp_parse(
@@ -167,7 +175,11 @@ class BiliParse(YtParser):
             message_json.raise_for_status()
             mj = message_json.json()
             if not (data := mj.get("data")):
-                raise ParseError(f"获取动态信息失败: {mj}")
+                match data.get("code"):
+                    case -352:
+                        raise ParseError("获取动态信息失败: -352 风控限制")
+                    case _:
+                        raise ParseError(f"获取动态信息失败: {mj}")
         message_formate = await formate_message("web", data.get("item"))
         img = await DynRender().run(message_formate)
 
@@ -185,7 +197,7 @@ class BiliParse(YtParser):
             try:
                 return await ImgHost(self.cfg.proxy).litterbox(f.name)
             except Exception:
-                raise ParseError("图片上传图床失败")
+                raise UploadError("图片上传图床失败")
 
     @staticmethod
     def change_source(url: str):
