@@ -1,4 +1,6 @@
 import re
+from dataclasses import dataclass
+from typing import Union
 
 import httpx
 from loguru import logger
@@ -6,6 +8,7 @@ from loguru import logger
 from ..base.base import Parser
 from ...types import Image, Video, Ani, MultimediaParseResult, ParseError
 from ...config import GlobalConfig
+from ...utiles.utile import cookie_ellipsis
 
 
 class TwitterParser(Parser):
@@ -16,27 +19,41 @@ class TwitterParser(Parser):
 
     async def parse(self, url: str) -> "MultimediaParseResult":
         url = await self.get_raw_url(url)
-        x = Twitter(self.cfg.proxy, cookie=self.cfg.cookie)
+        tweet = await self._parse(url)
+        return await self.media_parse(url, tweet)
+
+    async def _parse(self, url: str):
+        x = Twitter(self.cfg.proxy, cookie=None)
         try:
             tweet = await x.fetch_tweet(url)
         except Exception as e:
-            raise ParseError(e) from e
-        return await self.media_parse(url, tweet)
+            if any(s in str(e) for s in ("error -2",)):
+                if self.cfg.cookie:
+                    x2 = Twitter(self.cfg.proxy, cookie=self.cfg.cookie)
+                    try:
+                        tweet = await x2.fetch_tweet(url)
+                    except Exception as e2:
+                        raise ParseError(
+                            f"Twitter 账号可能已被封禁\n\n使用的Cookie: {cookie_ellipsis(self.cfg.cookie)}"
+                        ) from e2
+                else:
+                    raise ParseError(e) from e
+            else:
+                raise ParseError(e) from e
+        return tweet
 
     @staticmethod
     async def media_parse(url, tweet: "TwitterTweet"):
         media = []
-        for i, v in enumerate(tweet.media):
-            for t, m in v.items():
-                if t == "photo":
-                    path = Image(m)
-                elif t == "video":
-                    path = Video(m)
-                elif t == "animated_gif":
-                    path = Ani(path=m, ext="mp4")
-                else:
-                    continue
-                media.append(path)
+        for m in tweet.media:
+            match m:
+                case TwitterPhoto():
+                    path = Image(m.url)
+                case TwitterVideo():
+                    path = Video(m.url, height=m.height, width=m.width)
+                case TwitterAni():
+                    path = Ani(m.url, ext="mp4")
+            media.append(path)
         return MultimediaParseResult(desc=tweet.full_text, media=media, raw_url=url)
 
 
@@ -87,7 +104,10 @@ class Twitter:
                 headers=headers,
                 cookies=cookie,
             )
-        response.raise_for_status()
+        try:
+            response.raise_for_status()
+        except httpx.HTTPStatusError as he:
+            raise Exception(f"http_status_{he.response.status_code}") from he
         return self.parse(response.json())
 
     @staticmethod
@@ -99,10 +119,10 @@ class Twitter:
         if not result:
             raise ParseError("error -4: 帖子或用户不存在")
         if tweet := result.get("tweet"):
-            tweet_id = tweet["rest_id"]
+            tweet_id = tweet.get("rest_id", {})
             legacy: dict = tweet.get("legacy")
         else:
-            tweet_id = result["rest_id"]
+            tweet_id = result.get("rest_id", {})
             legacy: dict = result.get("legacy")
         if not legacy:
             if result.get("__typename") == "TweetTombstone":
@@ -111,15 +131,26 @@ class Twitter:
 
         full_text = legacy.get("full_text", "")
         media = legacy["entities"].get("media", [])
-        media = [
-            {
-                i["type"]: i["media_url_https"]
-                if i["type"] == "photo"
-                else i["video_info"]["variants"][-1]["url"]
-            }
-            for i in media
-        ]
-        return TwitterTweet(tweet_id=tweet_id, full_text=full_text, media=media)
+        medias = []
+        for i in media:
+            match i["type"]:
+                case "photo":
+                    medias.append(TwitterPhoto(url=i["media_url_https"]))
+                case "video":
+                    original_info = i.get("original_info", {})
+                    medias.append(
+                        TwitterVideo(
+                            url=i["video_info"]["variants"][-1]["url"],
+                            height=original_info.get("height", 0),
+                            width=original_info.get("width", 0),
+                        )
+                    )
+                case "animated_gif":
+                    medias.append(
+                        TwitterAni(url=i["video_info"]["variants"][-1]["url"])
+                    )
+
+        return TwitterTweet(tweet_id=tweet_id, full_text=full_text, media=medias)
 
     @staticmethod
     def get_id_by_url(url: str):
@@ -146,7 +177,12 @@ class Twitter:
 
 
 class TwitterTweet:
-    def __init__(self, tweet_id: str, full_text: str, media: list[dict]):
+    def __init__(
+        self,
+        tweet_id: str,
+        full_text: str,
+        media: list[Union["TwitterVideo", "TwitterPhoto", "TwitterAni"]],
+    ):
         self.tweet_id = tweet_id
         self.full_text = (
             re.sub(r"https://t\.co/[^\s,]+$", "", full_text) if media else full_text
@@ -154,4 +190,21 @@ class TwitterTweet:
         self.media = media
 
 
+@dataclass
+class TwitterVideo:
+    url: str
+    height: int
+    width: int
+
+
+@dataclass
+class TwitterPhoto:
+    url: str
+
+
+@dataclass
+class TwitterAni:
+    url: str
+
+
 __all__ = ["TwitterParser"]
