@@ -3,6 +3,8 @@ import shutil
 import time
 from pathlib import Path
 from typing import Callable, Generic, TypeVar, Literal, Awaitable
+
+from . import DownloadError
 from .media import Media, Video
 from ..utiles.utile import progress, img2base64
 from ..utiles.download_file import download_file
@@ -65,21 +67,23 @@ class ParseResult(ABC):
         if isinstance(self.media, list):
             path_list = []
             op = (Path(path) if path else config.save_dir).joinpath(f"{time.time_ns()}")
-            for i, image in enumerate(self.media):
-                if not image.is_url:
-                    path_list.append(image)
+            for i, media in enumerate(self.media):
+                if not media.is_url:
+                    path_list.append(media)
                     continue
                 try:
                     f = await download_file(
-                        image.path,
-                        f"{op}/{i}.{image.ext}",
+                        media.path,
+                        f"{op}/{i}.{media.ext}",
                         proxies=config.proxy,
                         headers=config.headers,
                     )
                 except Exception as e:
-                    raise Exception(f"下载失败: {e}")
-
-                path_list.append(image.__class__(f, ext=image.ext))
+                    shutil.rmtree(op)
+                    raise DownloadError(f"下载失败: {e}")
+                n_m = media.__class__(**vars(media))
+                n_m.path = f
+                path_list.append(n_m)
 
                 if callback:
                     await callback(
@@ -111,13 +115,15 @@ class ParseResult(ABC):
                     progress_args=callback_args,
                 )
             except Exception as e:
-                raise Exception(f"下载失败: {e}")
+                raise DownloadError(f"下载失败: {e}")
 
             # 小于10KB为下载失败
             if not os.stat(r).st_size > 10 * 1024:
                 os.remove(r)
-                raise Exception("下载失败")
-            return DownloadResult(self, self.media.__class__(r, ext=self.media.ext))
+                raise DownloadError("下载失败")
+            n_m = self.media.__class__(**vars(self.media))
+            n_m.path = r
+            return DownloadResult(self, n_m)
 
     async def summary(
         self,
@@ -215,7 +221,7 @@ class DownloadResult(Generic[T]):
         model: str = None,
         provider: Literal["openai"] = None,
         prompt: str = None,
-        transcriptions_provider: str = None,
+        transcriptions_provider: Literal["openai", "fast_whisper", "azure"] = None,
         transcriptions_api_key: str = None,
         transcriptions_base_url: str = None,
     ) -> "SummaryResult":
@@ -302,10 +308,10 @@ class DownloadResult(Generic[T]):
 
     @staticmethod
     async def _video_to_subtitles(
-        media_: Media,
+        media_: Video,
         api_key: str,
         base_url: str,
-        transcriptions_provider: str,
+        transcriptions_provider: Literal["openai", "fast_whisper", "azure"],
     ) -> str:
         if not media_.subtitles:
             tr = await Transcriptions(api_key=api_key, base_url=base_url).transcription(
